==> haskell-text-printer-0.5-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-printer
version: 0.5
id: text-printer-0.5-EEnxSm7ih2F3Cat1XqaxzY
key: text-printer-0.5-EEnxSm7ih2F3Cat1XqaxzY
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-printer
synopsis: Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.
category: Text
abi: 518b5a97bd0bf9a8613d7f4bea58e309
exposed: True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-printer-0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-printer-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-printer-0.5
hs-libraries: HStext-printer-0.5-EEnxSm7ih2F3Cat1XqaxzY
depends:
    base-4.12.0.0 bytestring-0.10.8.2 pretty-1.1.3.6 text-1.2.3.1
    text-latin1-0.3.1-9Jk52ccaV4CGspJYZunZZU
haddock-interfaces: /usr/share/doc/haskell-text-printer/html/text-printer.haddock
haddock-html: /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-printer-0.5-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-text-printer.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: text-printer
version: 0.5
id: text-printer-0.5-7FHeqcLtqQ36mC3re1zjRL
key: text-printer-0.5-7FHeqcLtqQ36mC3re1zjRL
license: BSD-3-Clause
copyright: 2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/text-printer
synopsis: Abstract interface for text builders/printers.
description:
    This package provides an interface for injecting text into monoids such as
    builders and printers.
category: Text
abi: e428f256eb6461456af8ac136a77e14c
exposed: True
exposed-modules:
    Text.Printer Text.Printer.Fractional Text.Printer.Integral
import-dirs: /usr/lib/ghc-8.6.5/site-local/text-printer-0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/text-printer-0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/text-printer-0.5
hs-libraries: HStext-printer-0.5-7FHeqcLtqQ36mC3re1zjRL
depends:
    base-4.12.0.0 bytestring-0.10.8.2 pretty-1.1.3.6 text-1.2.3.1
    text-latin1-0.3.1-F9gMENqLhQUKEeqgV2t8rB
haddock-interfaces: /usr/share/doc/haskell-text-printer/html/text-printer.haddock
haddock-html: /usr/share/doc/haskell-text-printer/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
